@@ -1,6 +1,6 @@
 package Log::Any::Plugin;
 # ABSTRACT: Adapter-modifying plugins for Log::Any
-$Log::Any::Plugin::VERSION = '0.008';
+$Log::Any::Plugin::VERSION = '0.009';
 use strict;
 use warnings;
 
@@ -37,7 +37,7 @@ Log::Any::Plugin - Adapter-modifying plugins for Log::Any
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -97,6 +97,68 @@ what options are supported.
 
 =back
 
+=head1 PLUGIN DEVELOPMENT
+
+=head2 Build Tools
+
+=over
+
+=item * You must have [cpanm|App::cpanminus](https://metacpan.org/pod/App::cpanminus) installed.
+
+=item * Then install [Dist::Zilla](http://dzil.org/) via `cpanm Dist::Zilla`. This is
+        a L<Dist::Zilla>-managed project.
+
+=back
+
+=head2 Setup Dependencies
+
+On initial check out of the project, set-up the required dependencies as follows:
+
+    # Get dependencies
+    dzil authordeps --missing | cpanm
+    dzil listdeps --author | cpanm
+
+Next run a basic test suite:
+
+    dzil test
+
+Install the necessary missed dependencies as needed via C<cpanm> and rerun
+tests till they execute successfully.
+
+For example, there's a L<known issue|https://rt.cpan.org/Public/Bug/Display.html?id=98689>
+requiring explicit installation of L<Module::Build::Version>.
+
+See the error logs as directed in the C<cpanm> output.
+
+=head2 Development
+
+A plugin's entry point is via its C<install> method which has the signature:
+
+    install($class, $adapter_class, %args)
+
+C<$adapter_class> is the L<Log::Any::Adapter> adapter class to be used, e.g.
+C<Stderr>.
+
+C<%args> is a hash of arguments to configure or customise the plugin.
+
+Plugins add new facilities or augment existing facilities, so it's hard to
+define confines of their scope. This module packages in several use-case
+driven plugins that may serve as examples E<mdash> check the
+L<SEE ALSO|"SEE ALSO"> section.
+
+Once a plugin is implemented, and tests added, re-run the L<Setup Dependencies|"Setup Dependencies">
+steps to get any new required dependencies.
+
+Next, run the full suite of tests through a sequence of:
+
+    dzil test
+    dzil test --author
+    dzil test --release
+
+Finally to remove any temporarily generated artifacts, run:
+
+    dzil clean
+
 =head1 SEE ALSO
 
 L<Log::Any>, L<Log::Any::Plugin::Levels>, L<Log::Any::Plugin::Stringify>
